@@ -95,6 +95,7 @@ ContactListWidget::ContactListWidget(QWidget *parent)
     KSharedConfigPtr config = KGlobal::config();
     KConfigGroup guiConfigGroup(config, "GUI");
 
+    d->groupMode = KTp::ContactsModel::NoGrouping;
     d->delegate = new ContactDelegate(this);
     d->compactDelegate = new ContactDelegateCompact(ContactDelegateCompact::Normal, this);
 
@@ -117,7 +118,7 @@ ContactListWidget::ContactListWidget(QWidget *parent)
     setEditTriggers(NoEditTriggers);
     setContextMenuPolicy(Qt::CustomContextMenu);
     if (KTp::kpeopleEnabled()) {
-        setIndentation(25);
+        setIndentation(18);
     } else {
         setIndentation(0);
     }
@@ -739,9 +740,9 @@ void ContactListWidget::mouseMoveEvent(QMouseEvent *event)
 
     mimeData->setData("application/vnd.telepathy.contact", encodedData);
 
-    kDebug() <<  index.data(KTp::NepomukUriRole).toString().toLatin1();
+    kDebug() <<  index.data(KTp::PersonIdRole).toString().toLatin1();
 
-    mimeData->setData("application/vnd.kpeople.uri", index.data(KTp::NepomukUriRole).toString().toLatin1());
+    mimeData->setData("application/vnd.kpeople.uri", index.data(KTp::PersonIdRole).toString().toLatin1());
 
     QPixmap dragIndicator = QPixmap::grabWidget(this, visualRect(index).adjusted(3,3,3,3));
 
@@ -789,14 +790,14 @@ void ContactListWidget::dropEvent(QDropEvent *event)
     } else if ((index.data(KTp::RowTypeRole).toInt() == KTp::ContactRowType || index.data(KTp::RowTypeRole).toInt() == KTp::PersonRowType) &&
                 event->mimeData()->hasFormat("application/vnd.kpeople.uri") && KTp::kpeopleEnabled()) {
         #ifdef HAVE_KPEOPLE
-        QUrl droppedUri(index.data(KTp::NepomukUriRole).toUrl());
-        QUrl draggedUri(event->mimeData()->data("application/vnd.kpeople.uri"));
+        QString droppedUri(index.data(KTp::PersonIdRole).toString());
+        QString draggedUri(event->mimeData()->data("application/vnd.kpeople.uri"));
         if(droppedUri != draggedUri) {
             KMenu menu;
             QAction *mergeAction = menu.addAction(i18n("Merge contacts"));
             QAction *result = menu.exec(mapToGlobal(event->pos()));
             if (result == mergeAction) {
-                KPeople::PersonsModel::createPersonFromUris(QList<QUrl>() << droppedUri << draggedUri);
+                KPeople::mergeContacts(QStringList() << droppedUri << draggedUri);
             }
             event->acceptProposedAction();
         }
