@@ -91,7 +91,6 @@ MainWidget::MainWidget(QWidget *parent)
     setupUi(this);
 
     m_filterBar->hide();
-    setWindowIcon(KIcon("telepathy-kde"));
     setAutoSaveSettings();
     setupTelepathy();
 
@@ -427,8 +426,9 @@ void MainWidget::setupGlobalMenu()
     if (!KStandardDirs::findExe("ktp-dialout-ui").isEmpty()) {
         contacts->addAction(m_makeCall);
     }
+    //temporarily disable until funcationality is restored in libkpeople
     if (KTp::kpeopleEnabled()) {
-        contacts->addAction(m_mergeContacts);
+//         contacts->addAction(m_mergeContacts);
     }
     contacts->addAction(m_settingsDialog);
     contacts->addSeparator();
@@ -502,7 +502,7 @@ void MainWidget::setupToolBar()
     }
 
     if (KTp::kpeopleEnabled()) {
-        settingsButtonMenu->addAction(m_mergeContacts);
+//         settingsButtonMenu->addAction(m_mergeContacts);
     }
 
     settingsButtonMenu->addSeparator();
